<?php

/**
 * @file
 * Administration page callbacks for the MSG91 module.
 */

/**
 * Form builder. Configure MSG91.
 */
function msg91_admin_settings() {

  $form['msg91_authKey'] = array(
    '#type' => 'textfield',
    '#title' => t('MSG91 Authentication ID'),
    '#default_value' => variable_get('msg91_authKey', 'Your Authentication Key'),
    '#required' => TRUE,
  );

  $form['msg91_senderID'] = array(
    '#type' => 'textfield',
    '#title' => t('MSG91 Sender ID'),
    '#default_value' => variable_get('msg91_senderID', 'HP-MSG91'),
    '#maxlength' => 6,
    '#description' => 'SMS received will have this Sender ID',
    '#required' => TRUE,
  );

  $form['msg91_route'] = array(
    '#type' => 'textfield',
    '#title' => t('MSG91 Route'),
    '#default_value' => variable_get('msg91_route', '4'),
    '#description' => 'Use number from 1-6 route for Transactional,Promotional SMS',
    '#required' => TRUE,
  );

  $form['#validate'][] = 'msg91_admin_form_validate';
  return system_settings_form($form);

}

/**
 * Validate MSG91 settings submission.
 */
function msg91_admin_form_validate($form, &$form_state) {
  $route = $form_state['values']['msg91_route'];
  $auth_key = $form_state['values']['msg91_authKey'];
  if ($route < 1 || $route > 6) {
    form_set_error('msg91_route', t('Route: Please enter number between 1 and 6.'));
  }

  $msg91_auth_url = "https://control.msg91.com/api/validate.php?authkey=" . $auth_key;
  $validate_response = drupal_http_request($msg91_auth_url);

  if ($validate_response->data != 'Valid') {
    form_set_error('msg91_authKey', t('Auth key you have entered doesnot validate.'));
  }

}
